@@ -5,12 +5,13 @@ terminal simpler, but without needing a user interface.
 """
 
 import img2pdf
+import importlib
 import math
 import os
 import sys
 from typing import Any, Iterable, Generator
 from pylejandria.constants import Number
-from pylejandria.gui import ask
+import pylejandria
 
 
 def center(text: str, space: int) -> str:
@@ -182,9 +183,11 @@ def image_to_pdf(
         remove: remove or not the given files.
     """
     if get_path is True:
-        path = ask('saveasfilename', 'PDF', defaultextension='*.pdf')
+        path = pylejandria.gui.ask(
+            'saveasfilename', 'PDF', defaultextension='*.pdf'
+        )
     if get_images is True:
-        images = ask('openfilenames', 'PNG', 'JPEG')
+        images = pylejandria.gui.ask('openfilenames', 'PNG', 'JPEG')
     if not (path and images):
         return
     with open(path, 'wb') as f:
@@ -326,11 +329,12 @@ def dict_zip(*dicts, strict: bool | None=False) -> None:
     regular zip to lists.
     Params:
         dicts:  all the dictionaries to zip.
-        strict: raise an error if any dictionary is exhausted. 
+        strict: raise an error if any dictionary is exhausted.
     """
     for items in zip(*[dict_.items() for dict_ in dicts], strict=strict):
         yield [[element for element in item] for item in items]
 
+
 def pair(items: list[Any], length: int) -> Generator:
     """
     Pairs n-elements from the list and yields it.
@@ -345,10 +349,23 @@ def pair(items: list[Any], length: int) -> Generator:
         items: list to be paired.
         length: length of the pairs.
     """
-    for i in range(len(items)-length-1):
+    for i in range(len(items)-length+1):
         yield items[i:i+length]
 
 
+def get_module(file: str) -> Any:
+    """
+    Loads and returns the given module.
+    Params:
+        file: absolute path of the file to be imported.
+    """
+    loader = importlib.machinery.SourceFileLoader('loaded_module', file)
+    spec = importlib.util.spec_from_loader('loaded_module', loader)
+    loaded_module = importlib.util.module_from_spec(spec)
+    loader.exec_module(loaded_module)
+    return loaded_module
+
+
 if __name__ == '__main__':
     d1 = {
         'a1': 1,
